# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-25 16:26
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0003_auto_20161025_1609'),
    ]

    operations = [
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateTimeField(blank=True, null=True, verbose_name='Start date')),
                ('end_date', models.DateTimeField(blank=True, null=True, verbose_name='End date')),
                ('can_be_done_remotely', models.BooleanField(default=False, verbose_name='This job can be done remotely')),
            ],
            options={
                'verbose_name': 'Job',
                'verbose_name_plural': 'Jobs',
            },
        ),
        migrations.CreateModel(
            name='JobDate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=20, null=True, verbose_name='Start date')),
                ('start_date', models.DateTimeField(blank=True, null=True, verbose_name='Start date')),
                ('end_date', models.DateTimeField(blank=True, null=True, verbose_name='End date')),
            ],
        ),
        migrations.CreateModel(
            name='Work',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('weekly_hours', models.PositiveSmallIntegerField(blank=True, null=True, verbose_name='Weekly hours')),
                ('description', models.CharField(blank=True, max_length=4000, null=True, verbose_name='Description')),
                ('can_be_done_remotely', models.BooleanField(default=False, verbose_name='This work can be done remotely.')),
                ('project', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ovp_projects.Project')),
            ],
            options={
                'verbose_name': 'work',
                'verbose_name_plural': 'works',
            },
        ),
        migrations.AlterModelOptions(
            name='role',
            options={'verbose_name': 'role', 'verbose_name_plural': 'roles'},
        ),
        migrations.AddField(
            model_name='role',
            name='details',
            field=models.TextField(blank=True, default=None, max_length=1024, null=True, verbose_name='Details'),
        ),
        migrations.AddField(
            model_name='role',
            name='name',
            field=models.CharField(blank=True, default=None, max_length=50, null=True, verbose_name='Role name'),
        ),
        migrations.AddField(
            model_name='role',
            name='prerequisites',
            field=models.TextField(blank=True, default=None, max_length=1024, null=True, verbose_name='Prerequisites'),
        ),
        migrations.AddField(
            model_name='role',
            name='vacancies',
            field=models.PositiveSmallIntegerField(blank=True, default=None, null=True, verbose_name='Vacancies'),
        ),
        migrations.AddField(
            model_name='job',
            name='dates',
            field=models.ManyToManyField(blank=True, null=True, to='ovp_projects.JobDate'),
        ),
        migrations.AddField(
            model_name='job',
            name='project',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ovp_projects.Project'),
        ),
    ]
