# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-11-15 17:45
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0011_auto_20161115_1744'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Role',
            new_name='VolunteerRole',
        ),
    ]
